@@ -11,7 +11,7 @@ __license__ = 'CC BY-NC-SA 4.0'
 
 from ..driver.base import (
     DriverType,
-    DriverKind,
+    DriverFamily,
 )
 
 from .core import (
